# Copyright (C) 2011  Canonical Ltd.
# Author: Colin Watson <cjwatson@ubuntu.com>

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# To use this module, you must set up %s/.isotracker_cookie.  To do this, go
# into your browser, e.g. for Firefox:
#   Edit > Preferences > Privacy > remove individual cookies
#      look for .qa.ubuntu.com and it will show Name and content fields
#   Create .isotracker_cookie and fill in the following
#	#HTTP Cookie File - to support use of post-amis-to-iso-tracker
#	.qa.ubuntu.com	JUNK1	JUNK2	JUNK3	JUNK4	<NAME>	<CONTENT>

import os
import httplib
import urllib
from cStringIO import StringIO
from xml.dom import minidom

cookiefile = os.path.expanduser('~%s/.isotracker_cookie' % os.getenv('USER'))

post_domain = 'iso.qa.ubuntu.com'
post_url = '/qatracker/admin/addbuild'


class HTTPError(Exception):
    """An unexpected HTTP response code was received."""

    def __init__(self, response):
        Exception.__init__(self)
        self.response = response

    def __str__(self):
        return "%s %s" % (self.response.status, self.response.reason)


def get_cookie_for_domain(post_domain):
    """
    Parse a traditional mozilla cookie file and return the first cookie
    matching our domain - assume we only need one, since otherwise we
    need to do a song and dance to pass multiple cookies to httplib
    """
    handle = open(cookiefile, 'r')
    for line in handle:
        if line.startswith('#'):
            continue
        domain, _, _, _, _, cookiename, cookieval = line.split()
        if not post_domain.endswith(domain):
            continue
        cookie = '%s=%s' % (cookiename, cookieval)
    handle.close()
    return cookie

def make_headers():
    cookie = get_cookie_for_domain(post_domain)
    return {
        'Content-type': 'application/x-www-form-urlencoded',
        'Cookie': cookie
    }

_connection = None
def get_connection():
    global _connection
    if _connection is None:
        _connection = httplib.HTTPConnection(post_domain)
    return _connection

_index = None
def get_index():
    global _index
    if _index is None:
        conn = get_connection()
        conn.request('GET', post_url, headers=make_headers())
        _index = StringIO(conn.getresponse().read())
    else:
        _index.seek(0)
    return _index

def default_milestone():
    doc = minidom.parse(get_index())

    for node in doc.getElementsByTagName('select'):
        if node.getAttribute('name') == 'isota_release':
            for option in node.childNodes:
                if (option.nodeType == option.ELEMENT_NODE and
                    option.getAttribute('selected')):
                    return option.getAttribute('value')
    else:
        raise KeyError("No default milestone selected")

def product_code(product):
    doc = minidom.parse(get_index())

    for tr in doc.getElementsByTagName('tr'):
        try:
            if tr.firstChild.firstChild.data != product:
                continue
        except AttributeError:
            continue
        for input in tr.getElementsByTagName('input'):
            if input.getAttribute('name') == 'isota_case[]':
                return int(input.getAttribute('value'))
    else:
        raise KeyError("Product '%s' not found" % product)

def post_build(product, version, milestone=None):
    conn = get_connection()
    if not isinstance(product, int):
        product = product_code(product)
    if milestone is None:
        milestone = default_milestone()
    params = urllib.urlencode({
        'isota_case[]': product,
        'isota_version': version,
        'isota_addisoadv': 'Add build(s)',
        'isota_release': milestone,
    })
    conn.request('POST', post_url, params, make_headers())
    response = conn.getresponse()
    if response.status != 302:
        raise HTTPError(response)
    # flush the response
    response.read()

def products():
    doc = minidom.parse(get_index())

    for tr in doc.getElementsByTagName('tr'):
        for td in tr.childNodes:
            try:
                if td.tagName != 'td':
                    continue
            except AttributeError:
                continue
            for input in td.childNodes:
                try:
                    if input.tagName != 'input':
                        continue
                except AttributeError:
                    continue
                if input.getAttribute('name') == 'isota_case[]':
                    yield tr.firstChild.firstChild.data
