#!/usr/bin/python

# Copyright (C) 2010, 2012  Canonical Ltd.
# Author: Colin Watson <cjwatson@ubuntu.com>

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Filter a list of new source packages.

The output will show those packages that have not been previously published
in Ubuntu.  These packages can be synced without further checking, while
other packages require investigation of why they were removed to see whether
they should be on the sync blacklist."""

from __future__ import print_function

import sys
from optparse import OptionParser

from launchpadlib.launchpad import Launchpad


CONSUMER_KEY = "new-source-filter.py"


def check(archive, src):
    records = archive.getPublishedSources(source_name=src, exact_match=True)
    return not records[:1]

def main():
    parser = OptionParser(usage="usage: %prog [options] <input")
    parser.add_option(
        "-l", "--launchpad", dest="launchpad_instance", default="production")
    options, args = parser.parse_args()
    if args:
        parser.error("This program does not accept any non-option arguments.")

    launchpad = Launchpad.login_with(CONSUMER_KEY, options.launchpad_instance)
    ubuntu = launchpad.distributions['ubuntu']
    archive = ubuntu.main_archive

    output = []
    for line in sys.stdin:
        line = line.strip()
        if check(archive, line):
            output.append(line)
    print('\n'.join(sorted(output)))

if __name__ == '__main__':
    main()
